const pool = require('../db');

exports.showReviews = async (req, res) => {
    const productId = req.params.id;
    const currentUserEmail = req.session.userIdEmail;

    try {
        const [product] = await pool.query('SELECT * FROM products WHERE product_id = ?', [productId]);
        const [reviews] = await pool.query(`
            SELECT r.*, u.email
            FROM reviwe r
            JOIN users u ON r.owner = u.id
            WHERE r.product_id = ?`, [productId]);

        res.render('reviews', { product: product[0], reviews, currentUserEmail });
    } catch (err) {
        res.status(500).send('เกิดข้อผิดพลาด: ' + err.message);
    }
};

exports.addReview = async (req, res) => {
    const productId = req.params.id;
    const { content } = req.body;
    const userEmail = req.session.userIdEmail;

    try {
        const [user] = await pool.query('SELECT id FROM users WHERE email = ?', [userEmail]);
        
        // ตรวจสอบว่าพบผู้ใช้หรือไม่
        if (!user || user.length === 0 || !user[0]) {
            return res.status(404).send('ไม่พบผู้ใช้งาน');
        }

        await pool.query('INSERT INTO reviwe (product_id, owner, content) VALUES (?, ?, ?)', [productId, user[0].id, content]);

        res.redirect(`/product/${productId}/reviews`);
    } catch (err) {
        res.status(500).send('เกิดข้อผิดพลาด: ' + err.message);
    }
};

exports.deleteReview = async (req, res) => {
    const { id, reviewId } = req.params;
    const userEmail = req.session.userIdEmail;

    try {
        const [user] = await pool.query('SELECT id FROM users WHERE email = ?', [userEmail]);

        // ตรวจสอบว่าพบผู้ใช้หรือไม่
        if (!user || user.length === 0 || !user[0]) {
            return res.status(404).send('ไม่พบผู้ใช้งาน');
        }

        await pool.query('DELETE FROM reviwe WHERE reviwe_id = ? AND owner = ?', [reviewId, user[0].id]);

        res.redirect(`/product/${id}/reviews`);
    } catch (err) {
        res.status(500).send('เกิดข้อผิดพลาด: ' + err.message);
    }
};

exports.editReviewForm = async (req, res) => {
    const { id, reviewId } = req.params;
    try {
        const [reviews] = await pool.query('SELECT * FROM reviwe WHERE reviwe_id = ?', [reviewId]);

        if (!reviews || reviews.length === 0) {
            return res.status(404).send('ไม่พบรีวิวนี้');
        }

        res.render('editReview', { product_id: id, review: reviews[0] });
    } catch (err) {
        res.status(500).send('เกิดข้อผิดพลาด: ' + err.message);
    }
};

exports.updateReview = async (req, res) => {
    const { id, reviewId } = req.params;
    const { content } = req.body;
    const userEmail = req.session.userIdEmail;

    try {
        const [user] = await pool.query('SELECT id FROM users WHERE email = ?', [userEmail]);

        // ตรวจสอบว่าพบผู้ใช้หรือไม่
        if (!user || user.length === 0 || !user[0]) {
            return res.status(404).send('ไม่พบผู้ใช้งาน');
        }

        await pool.query('UPDATE reviwe SET content = ? WHERE reviwe_id = ? AND owner = ?', [content, reviewId, user[0].id]);
        res.redirect(`/product/${id}/reviews`);
    } catch (err) {
        res.status(500).send('เกิดข้อผิดพลาด: ' + err.message);
    }
};
